@@ -108,7 +108,7 @@ gok_button_init (GokButton* gok_button)
 *
 * Returns: A pointer to the new button, NULL if it could not be created.
 */
-GtkWidget* gok_button_new_with_label (const gchar *pText)
+GtkWidget* gok_button_new_with_label (const gchar *pText, GokImagePlacementPolicy align)
 {
 	GokButton* pNewButton = NULL;
 
@@ -123,7 +123,10 @@ GtkWidget* gok_button_new_with_label (const gchar *pText)
 		/* add the label to it */
 		pNewButton->pLabel = gtk_label_new (pText);
 		gtk_widget_show (GTK_WIDGET (pNewButton->pLabel));
-		gtk_box_pack_end (GTK_BOX (pNewButton->pBox), pNewButton->pLabel, TRUE, TRUE, 0);
+		if (align == IMAGE_PLACEMENT_LEFT)
+			gtk_box_pack_end (GTK_BOX (pNewButton->pBox), pNewButton->pLabel, TRUE, TRUE, 0);
+		else
+			gtk_box_pack_start (GTK_BOX (pNewButton->pBox), pNewButton->pLabel, TRUE, TRUE, 0);
 	}
 	return GTK_WIDGET (pNewButton);
 }
@@ -136,7 +139,7 @@ GtkWidget* gok_button_new_with_label (const gchar *pText)
 *
 * Returns: A pointer to the new button, NULL if it could not be created.
 **/
-GtkWidget* gok_button_new_with_image (GtkWidget *image)
+GtkWidget* gok_button_new_with_image (GtkWidget *image, GokImagePlacementPolicy align)
 {
 	GokButton* pNewButton = NULL;
 	
@@ -150,7 +153,10 @@ GtkWidget* gok_button_new_with_image (GtkWidget *image)
 		/* add the image to it */
 		pNewButton->pImage = image;
 		gtk_widget_show (pNewButton->pImage);
-		gtk_box_pack_start (GTK_BOX (pNewButton->pBox), pNewButton->pImage, FALSE, FALSE, 0);
+		if (align == IMAGE_PLACEMENT_LEFT)
+			gtk_box_pack_start (GTK_BOX (pNewButton->pBox), pNewButton->pImage, FALSE, FALSE, 0);
+		else
+			gtk_box_pack_end (GTK_BOX (pNewButton->pBox), pNewButton->pImage, FALSE, FALSE, 0);
 	}
 
 	return GTK_WIDGET (pNewButton);
