@@ -243,12 +243,13 @@ void gok_editor_new_file ()
 */
 void gok_editor_open_file()
 {
-	GtkFileSelection* pDialogFilename;
+	GtkWidget* pDialogFilename;
 	GtkWidget* pDialog;
 	gint response;
-	const gchar* filename;
+	gchar* filename;
 	GtkWidget* pEntry;
 	GokKey* pKey;
+	GtkFileFilter *filter;
 	
 	if (m_bFileModified == TRUE)
 	{
@@ -269,34 +270,43 @@ void gok_editor_open_file()
 	}
 
 	/* create the file selector dialog */
-	pDialogFilename = (GtkFileSelection*)gtk_file_selection_new (_("Select keyboard file for editing"));
+	pDialogFilename = gtk_file_chooser_dialog_new (_("Select keyboard file for editing"),
+						       GTK_WINDOW(m_pWindowEditor),
+						       GTK_FILE_CHOOSER_ACTION_OPEN,
+						       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						       GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+						       NULL);
 
 	/* display only .kbd files */
 	/* TODO - this is not working! Why?? */
-	gtk_file_selection_complete (pDialogFilename, "*.kbd");
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _(".kbd files"));
+	gtk_file_filter_add_pattern (filter, "*.kbd");
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(pDialogFilename), filter);
 	
-   /* display that file selector dialog */
+	/* display that file selector dialog */
 	response = gtk_dialog_run (GTK_DIALOG(pDialogFilename));
 
-	if (response == GTK_RESPONSE_CANCEL)
+	if (response != GTK_RESPONSE_OK)
 	{
 		/* destroy the file selector dialog */
-		gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+		gtk_widget_destroy (pDialogFilename);
 
 		return;
 	}
 	
 	/* get the file name */
-	filename = gtk_file_selection_get_filename (pDialogFilename);
+	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(pDialogFilename));
 	
 	/* is this a GOK keyboard file? */
 	if ((strlen(filename) < 4) ||
 		(strcmp(filename + (strlen(filename)-4), ".kbd") != 0))
 	{
 		/* no, destroy the file selector dialog */
-		gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+		gtk_widget_destroy (pDialogFilename);
 
-		gok_editor_message_filename_bad ((gchar*)filename);		
+		gok_editor_message_filename_bad (filename);
+		g_free (filename);
 		return;
 	}
 	
@@ -305,11 +315,10 @@ void gok_editor_open_file()
 	{
 		g_free (m_pFilename);
 	}
-	m_pFilename = (gchar*)g_malloc (strlen (filename) + 1);
-	strcpy (m_pFilename, filename);
+	m_pFilename = filename;
 	
 	/* destroy the file selector dialog */
-	gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+	gtk_widget_destroy (pDialogFilename);
 
 	/* delete the previous keyboard */
 	if (m_pKeyboard != NULL)
@@ -526,7 +535,7 @@ void gok_editor_add_key ()
 		pNewKey->Left = col;
 		pNewKey->Right = col + 1;
 		gok_log("adding key {top [%d] bottom [%d] left [%d] right [%d]}",pNewKey->Top,pNewKey->Bottom,pNewKey->Left,pNewKey->Right);
-		gok_key_add_label (pNewKey, _("label"), NULL);
+		gok_key_add_label (pNewKey, _("label"), 0, 0);
 		
 		gok_editor_touch_file(TRUE);
 		gok_editor_update_keyboard(m_pKeyboard);
@@ -799,9 +808,10 @@ gboolean gok_editor_save_keyboard (GokKeyboard* pKeyboard, gchar* Filename)
 		while (pLabel != NULL)
 		{
 			fputs ("\t\t<GOK:label", pFile);
-			if (strlen (pLabel->Modifier) != 0)
+			if (pLabel->modifiers != 0)
 			{
-				fprintf (pFile, " modifier=\"%s\"", pLabel->Modifier);
+				fprintf (pFile, " modifier=\"%s\"", 
+					 gok_modifier_first_name_from_mask (pLabel->modifiers));
 			}
 			fprintf (pFile, ">%s</GOK:label>\n", pLabel->Text);
 			
@@ -942,9 +952,10 @@ gboolean gok_editor_save_current_keyboard ()
 */
 gboolean gok_editor_save_current_keyboard_as ()
 {
-	GtkFileSelection* pDialogFilename;
+	GtkWidget* pDialogFilename;
 	gint response;
-	const gchar* filename;
+	gchar* filename;
+	GtkFileFilter *filter;
 	
 	if (m_pKeyboard != NULL)
 	{
@@ -952,33 +963,42 @@ gboolean gok_editor_save_current_keyboard_as ()
 		{
 			/* get name of keyboard filename */
 			/* create the file selector dialog */
-			pDialogFilename = (GtkFileSelection*)gtk_file_selection_new ("Save keyboard file as");
-		
+			pDialogFilename = gtk_file_chooser_dialog_new (_("Save keyboard file as"),
+								       GTK_WINDOW(m_pWindowEditor),
+								       GTK_FILE_CHOOSER_ACTION_SAVE,
+								       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+								       GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+								       NULL);
+
 			/* display only .kbd files */
 			/* TODO - this is not working! Why?? */
-			gtk_file_selection_complete (pDialogFilename, "*.kbd");
-			
-		   /* display that file selector dialog */
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, _(".kbd files"));
+			gtk_file_filter_add_pattern (filter, "*.kbd");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(pDialogFilename), filter);
+	
+			/* display that file selector dialog */
 			response = gtk_dialog_run (GTK_DIALOG(pDialogFilename));
 		
-			if (response == GTK_RESPONSE_CANCEL)
+			if (response != GTK_RESPONSE_OK)
 			{
 				/* destroy the file selector dialog */
-				gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+				gtk_widget_destroy (pDialogFilename);
 				return FALSE;
 			}
 			
 			/* get the file name */
-			filename = gtk_file_selection_get_filename (pDialogFilename);
+			filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (pDialogFilename));
 			
 			/* is this a GOK keyboard file? */
 			if ((strlen(filename) < 4) ||
 				(strcmp(filename + (strlen(filename)-4), ".kbd") != 0))
 			{
 				/* no, destroy the file selector dialog */
-				gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+				gtk_widget_destroy (pDialogFilename);
 				
-				gok_editor_message_filename_bad ((gchar*)filename);		
+				gok_editor_message_filename_bad (filename);
+				g_free (filename);
 				return FALSE;
 			}
 			
@@ -987,14 +1007,13 @@ gboolean gok_editor_save_current_keyboard_as ()
 			{
 				g_free (m_pFilename);
 			}
-			m_pFilename = (gchar*)g_malloc (strlen (filename) + 1);
-			strcpy (m_pFilename, filename);
+			m_pFilename = filename;
 			
 			/* destroy the file selector dialog */
-			gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+			gtk_widget_destroy (pDialogFilename);
 
 			/* save the keyboard under this filename */
-			gok_editor_save_keyboard (m_pKeyboard, (gchar*)filename);
+			gok_editor_save_keyboard (m_pKeyboard, filename);
 		}
 	}
 	
