@@ -46,6 +46,8 @@
 
 #define xmlStrPrefix(a, b) (!xmlStrncmp((a), (b), xmlStrlen(b)))
 
+long keysym2ucs(KeySym keysym); /* from keysym2ucs.c */
+
 gchar m_TextEmpty[]="";
 
 char m_label[XkbKeyNameLength + 1];
@@ -233,6 +235,7 @@ gok_key_label_from_keycode (KeyCode keycode, Display *display, unsigned int modm
   XkbStateRec xkb_state;
   int level;
   int type;
+  long ucs;
 
   if (modmask == GOK_MODMASK_CURRENT) {
           XkbGetState (display, XkbUseCoreKbd, &xkb_state);
@@ -241,15 +244,23 @@ gok_key_label_from_keycode (KeyCode keycode, Display *display, unsigned int modm
   type =  gok_key_get_xkb_type_index (gok_keyboard_get_xkb_desc (), keycode, group);
   level = gok_key_level_for_type (display, gok_keyboard_get_xkb_desc(), type, &modmask);
   keysym = XkbKeycodeToKeysym (display, keycode, group, level);
-  /* workaround; XSun gets nbytes wrong, so we truncate to the largest legal value */
-  nbytes = MIN (XkbTranslateKeySym (display, &keysym, modmask, buf, 19, &extra_rtn), 19); 
-  if (nbytes && g_unichar_isgraph (g_utf8_get_char_validated (buf, nbytes))) {
+  if ((ucs = keysym2ucs (keysym)) <= 0) 
+  {
+      /* workaround; XSun gets nbytes wrong, so we truncate to the largest legal value */  
+      nbytes = MIN (XkbTranslateKeySym (display, &keysym, modmask, buf, 19, &extra_rtn), 19); 
+      if (nbytes && g_unichar_isgraph (g_utf8_get_char_validated (buf, nbytes))) {
 	  return g_strndup (buf, nbytes);
-  }
-  else {  /* try again, without modifiers...*/
+      }
+      else {  /* try again, without modifiers...*/
 	  nbytes = MIN (XkbTranslateKeySym (display, &keysym, 0, buf, 19, &extra_rtn), 19);
 	  return gok_key_label_from_keysym_string (
-		  (nbytes && g_unichar_isgraph (g_utf8_get_char_validated (buf, nbytes))) ? buf : XKeysymToString (keysym));
+	      (nbytes && g_unichar_isgraph (g_utf8_get_char_validated (buf, nbytes))) ? buf : XKeysymToString (keysym));
+      }
+  }
+  else
+  {
+      buf[g_unichar_to_utf8 (ucs, buf)] = '\0';
+      return gok_key_label_from_keysym_string (buf);
   }
 }
 
@@ -728,11 +739,6 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 				pKey->Style = KEYSTYLE_INSENSITIVE;
 		}
 		else {
-			gok_gconf_get_bool (gconf_client_get_default(),
-				GOK_GCONF_PREFS_LOCKED, &settings_locked);
-			if (settings_locked) {
-				gok_settingsdialog_lock ();
-			}
 			pKey->Style = KEYSTYLE_SETTINGS;
 		}
 	}
@@ -950,7 +956,7 @@ if (strcmp ((char *)pStringAttributeValue, "toggle") == 0)
 				}
 				g_strfreev (tokens);
 			}
-			gok_keylabel_new (pKey, (char *)g_strstrip (xmlNodeGetContent (pNodeKeyChild)),
+			gok_keylabel_new (pKey, g_strstrip (xmlNodeGetContent (pNodeKeyChild)),
 					  modifier, modmask);
 			pKey->has_text = TRUE;
 		}
