@@ -241,8 +241,8 @@ GokOutput* gok_output_new_from_xml (xmlNode* pNode)
 		gok_log_x ("Output type '%s' not correct!\n", pStringAttributeValue);
 		return NULL;
 	}
-	
-	return gok_output_new (typeOutput, (gchar *) xmlNodeGetContent (pNode), flagOutput);
+
+	return gok_output_new (typeOutput, g_strstrip (xmlNodeGetContent (pNode)), flagOutput);
 }
 
 /**
