@@ -50,11 +50,14 @@ void gok_spy_close(void);       /* call this when shutting down */
 void gok_spy_stop (void);       /* call this first, as soon as you start shutting down */
  
 /* listener support */
-void gok_spy_register_appchangelistener(AppChangeListener* callback); 
-void gok_spy_deregister_appchangelistener(AppChangeListener* callback); 
+void gok_spy_register_appchangelistener(AccessibleChangeListener* callback); 
+void gok_spy_deregister_appchangelistener(AccessibleChangeListener* callback); 
  
-void gok_spy_register_windowchangelistener(AppChangeListener* callback); 
-void gok_spy_deregister_windowchangelistener(AppChangeListener* callback); 
+void gok_spy_register_windowchangelistener(AccessibleChangeListener* callback); 
+void gok_spy_deregister_windowchangelistener(AccessibleChangeListener* callback); 
+
+void gok_spy_register_objectstatelistener(AccessibleChangeListener* callback); 
+void gok_spy_deregister_objectstatelistener(AccessibleChangeListener* callback); 
 
 void gok_spy_register_mousebuttonlistener(MouseButtonListener* callback); 
 void gok_spy_deregister_mousebuttonlistener(MouseButtonListener* callback); 
