@@ -126,7 +126,7 @@ gboolean gok_windowlister_show()
 	pKey->Bottom = 1;
 	pKey->Left = 0;
 	pKey->Right = 1;
-	gok_key_add_label (pKey, _("back"), NULL);
+	gok_key_add_label (pKey, _("back"), 0, 0);
 	pKeyPrevious = pKey;
 
 	/* build window keys */
@@ -149,7 +149,7 @@ gboolean gok_windowlister_show()
 			pKey->Left = column;
 			pKey->Right = column + 1;
 			
-			gok_key_add_label (pKey, (char*)(wnck_window_get_name (window_list_entry->data)), NULL);
+			gok_key_add_label (pKey, (char*)(wnck_window_get_name (window_list_entry->data)), 0, 0);
 			
 			pKey->pGeneral = window_list_entry->data;  
 	
