@@ -76,7 +76,7 @@ struct _GokWordCompleteClass
 	gchar*    (* unichar_push) (GokWordComplete *complete, gunichar letter);
 	GokWordCompletionCharacterCategory (* unichar_get_category) (GokWordComplete *complete, gunichar letter);
 	gchar*    (* get_word_part) (GokWordComplete *complete);
-        gchar*    (* get_aux_dictionary) (GokWordComplete *complete);
+        const gchar*    (* get_aux_dictionary) (GokWordComplete *complete);
 	gboolean  (* set_aux_dictionary) (GokWordComplete *complete, const gchar *dict_path);
 };
 
